==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/eventing/v1/TriggerFilterBuilder.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class TriggerFilterBuilder extends TriggerFilterFluentImpl<TriggerFilterBuilder> implements VisitableBuilder<TriggerFilter,TriggerFilterBuilder> {

    TriggerFilterFluent<?> fluent;
    Boolean validationEnabled;

    public TriggerFilterBuilder() { 
        this(true);
    }


    public TriggerFilterBuilder(Boolean validationEnabled) { 
        this(new TriggerFilter(), validationEnabled);
    }


    public TriggerFilterBuilder(TriggerFilterFluent<?> fluent) { 
        this(fluent, true);
    }


    public TriggerFilterBuilder(TriggerFilterFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new TriggerFilter(), validationEnabled);
    }


    public TriggerFilterBuilder(TriggerFilterFluent<?> fluent,TriggerFilter instance) { 
        this(fluent, instance, true);
    }


    public TriggerFilterBuilder(TriggerFilterFluent<?> fluent,TriggerFilter instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withAttributes(instance.getAttributes()); 
        this.validationEnabled = validationEnabled; 
    }


    public TriggerFilterBuilder(TriggerFilter instance) { 
        this(instance,true);
    }


    public TriggerFilterBuilder(TriggerFilter instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withAttributes(instance.getAttributes()); 
        this.validationEnabled = validationEnabled; 
    }


    public TriggerFilter build() {
        TriggerFilter buildable = new TriggerFilter(fluent.getAttributes());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        TriggerFilterBuilder that = (TriggerFilterBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/v1/TriggerFilterBuilder.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class TriggerFilterBuilder extends TriggerFilterFluentImpl<TriggerFilterBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<TriggerFilter,TriggerFilterBuilder> {

    TriggerFilterFluent<?> fluent;
    Boolean validationEnabled;

    public TriggerFilterBuilder() {
        this(true);
    }

    public TriggerFilterBuilder(Boolean validationEnabled) {
        this(new TriggerFilter(), validationEnabled);
    }

    public TriggerFilterBuilder(TriggerFilterFluent<?> fluent) {
        this(fluent, true);
    }

    public TriggerFilterBuilder(TriggerFilterFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new TriggerFilter(), validationEnabled);
    }

    public TriggerFilterBuilder(TriggerFilterFluent<?> fluent,TriggerFilter instance) {
        this(fluent, instance, true);
    }

    public TriggerFilterBuilder(TriggerFilterFluent<?> fluent,TriggerFilter instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAttributes(instance.getAttributes()); 
        this.validationEnabled = validationEnabled; 
    }

    public TriggerFilterBuilder(TriggerFilter instance) {
        this(instance,true);
    }

    public TriggerFilterBuilder(TriggerFilter instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAttributes(instance.getAttributes()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.v1.EditableTriggerFilter build() {
        EditableTriggerFilter buildable = new EditableTriggerFilter(fluent.getAttributes());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        TriggerFilterBuilder that = (TriggerFilterBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
